BcHitResult class

Constructors

BcHitResult(List<BcTrajectoryData> trajectory, BcTerminationReason reason)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reason → BcTerminationReason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trajectory → List<BcTrajectoryData>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited